# Future changes

Here should be the updates to the project. As they are completed they will be added to the next version.

- Add `pre-commit` to lint and format.

# 0.1.2

Fixed:
    - `PyLanguages.report_compact_plain` now counts correctly the
    summarised languages.


Added typing info for:
    - `Languages.total_plain`.
    - `Languages.report_compact_plain`.

# 0.1.1

Updates/Fixes in docs:

- `index.md`: add binary versions available.

- Time execution comparison example in docs.

- Updated `mkdocs.yml`, changed Examples to Usage.

- Add API reference in docs.

# 0.1.0

First version released to PyPI.